@@ -662,3 +662,38 @@ fn just_pid() {
 
   assert_eq!(stdout.parse::<u32>().unwrap(), pid);
 }
+
+#[test]
+fn blake3() {
+  Test::new()
+    .justfile("x := blake3('5943ee37-0000-1000-8000-010203040506')")
+    .args(["--evaluate", "x"])
+    .stdout("026c9f740a793ff536ddf05f8915ea4179421f47f0fa9545476076e9ba8f3f2b")
+    .run();
+}
+
+#[test]
+fn blake3_file() {
+  Test::new()
+    .justfile("x := blake3_file('sub/blakefile')")
+    .tree(tree! {
+      sub: {
+        blakefile: "just is great\n",
+      }
+    })
+    .current_dir("sub")
+    .args(["--evaluate", "x"])
+    .stdout("8379241877190ca4b94076a8c8f89fe5747f95c62f3e4bf41f7408a0088ae16d")
+    .run();
+}
+
+#[cfg(unix)]
+#[test]
+fn canonicalize() {
+  Test::new()
+    .args(["--evaluate", "x"])
+    .justfile("x := canonicalize('foo')")
+    .symlink("justfile", "foo")
+    .stdout_regex(".*/justfile")
+    .run();
+}
